==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/space/messages/sv/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Det här forumet saknar innehåll!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Det här forumet saknar innehåll!</b><br>Börja med att göra ett inlägg här...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Du är inte medlem i det här forumet och det finns ännu inget publikt innehåll!</b>',
    '<strong>About</strong> the Space' => '<strong>Om</strong> forumet',
    '<strong>About</strong> your membership' => '<strong>Om</strong> ditt medlemskap',
    '<strong>Confirm</strong> image deletion' => '<strong>Bekräfta</strong> borttag av bild',
    '<strong>Invite</strong> members' => '<strong>Bjud in</strong> medlemmar',
    '<strong>New</strong> member request' => '<strong>Nya</strong> medlemsförfrågningar',
    '<strong>New</strong> spaces' => '<strong>Nya</strong> forum',
    '<strong>Request</strong> space membership' => '<strong>Ansök om</strong> medlemskap i forumet',
    '<strong>Space</strong> followers' => '<strong>Forumets</strong> följare',
    '<strong>Space</strong> members' => '<strong>Forumets</strong> medlemmar',
    '<strong>Space</strong> menu' => '<strong>Forum</strong> meny',
    '<strong>Space</strong> tags' => '<strong>Forum</strong>-taggar',
    '<strong>Spaces</strong>' => '<strong>Forum</strong>',
    'About' => 'Om',
    'Accept' => 'Acceptera',
    'Accept Invite' => 'Acceptera inbjudan',
    'Add users without invitation' => 'Lägg till användare utan inbjudan',
    'Admin' => 'Admin',
    'Administrator:' => 'Administratör:',
    'Administrators' => 'Administratörer',
    'Any' => 'Några',
    'Application message' => 'Meddelande för ansökan',
    'Archived' => 'Arkiverad',
    'As owner you cannot revoke your membership!' => 'Som ägare kan du inte avsäga ditt medlemskap!',
    'Blocked users' => 'Blockerade användare',
    'By Name' => 'Vid namn',
    'Cancel' => 'Avbryt',
    'Close' => 'Stäng',
    'Color' => 'Färg',
    'Could not request membership!' => 'Kunde inte begära medlemskap!',
    'Created At' => 'Skapad',
    'Created By' => 'Skapad av',
    'Decline' => 'Avböj',
    'Decline Invite' => 'Avböj inbjudan',
    'Default' => 'Standard',
    'Default content visibility' => 'Innehållets synlighet som standard',
    'Delete' => 'Ta bort',
    'Description' => 'Beskrivning',
    'Do you really want to delete your profile image?' => 'Vill du verkligen radera profilbilden?',
    'Do you really want to delete your title image?' => 'Vill du verkligen radera titelbilden?',
    'Done' => 'Klart',
    'Email addresses' => 'E-postadress',
    'Everyone can enter' => 'Vem som helst kan gå med',
    'Find Spaces by their description or by their tags' => 'Hitta forum genom deras beskrivning eller efter deras taggar',
    'Follow' => 'Följ',
    'Followers' => 'Följare',
    'Following' => 'Följer',
    'Guests' => 'Gäster',
    'Hide Members sidebar in the stream page.' => 'Dölj sidofältet med medlemmar på flödessidan',
    'Homepage' => 'Hemsida',
    'Homepage (Guests)' => 'Hemsida (Gäster)',
    'Invite' => 'Bjud in',
    'Invite and request' => 'Inbjudan och förfrågan',
    'Invite by email' => 'Inbjudan via e-post',
    'Invites' => 'Inbjudningar',
    'Join' => 'Anslut',
    'Join Policy' => 'Policy för att ansluta',
    'Last Visit' => 'Senaste besök',
    'Login' => 'Logga in',
    'Max. 100 characters.' => 'Max 100 tecken',
    'Member' => 'Medlem',
    'Member since' => 'Medlem sedan',
    'Members' => 'Medlemmar',
    'Moderator' => 'Moderator',
    'Moderator:' => 'Moderator:',
    'Moderators' => 'Moderatorer',
    'My Space List' => 'Min lista med forum',
    'My space summary' => 'Min forumöversikt',
    'Name' => 'Namn',
    'Neither..nor' => 'Varken eller',
    'New user by e-mail (comma separated)' => 'Ny användare via e-post (komma separerade)',
    'New user?' => 'Ny användare?',
    'Newest first' => 'Nyast först',
    'No results found!' => 'Inga resultat funna!',
    'No spaces found.' => 'Inga forum funna.',
    'Oldest first' => 'Äldst först',
    'Only by invite' => 'Endast via inbjudan',
    'Originator User ID' => 'Ursprungligt användar ID',
    'Owner' => 'Ägare',
    'Owner:' => 'Ägare:',
    'Pending' => 'Väntar',
    'Pick users' => 'Välj användare',
    'Please shortly introduce yourself, to become an approved member of this space.' => 'Vänligen presentera dig lite kort, för att bli godkänd som medlem i detta forum.',
    'Posts' => 'Inlägg',
    'Private' => 'Privat',
    'Private (Invisible)' => 'Privat (osynlig)',
    'Public' => 'Publik',
    'Public (Members & Guests)' => 'Publik (medlemmar &amp; gäster)',
    'Public (Members only)' => 'Publik (endast medlemmar)',
    'Public (Registered users only)' => 'Publik (endast registrerade användare)',
    'Request Message' => 'Begär meddelande',
    'Role' => 'Roll',
    'Search...' => 'Sök...',
    'See all' => 'Se alla',
    'Select all registered users' => 'Välj alla registrerade användare',
    'Send' => 'Skicka',
    'Settings' => 'Inställningar',
    'Settings could not be saved!' => 'Inställningarna kunde inte sparas!',
    'Show all' => 'Visa alla',
    'Shown on About Page.' => 'Visas på Om-sidan',
    'Sorry, you are not allowed to leave this space!' => 'Tyvärr, du har inte tillåtelse att lämna detta forum!',
    'Sorting' => 'Sortering',
    'Space' => 'Forum',
    'Space Visibility' => 'Forumets synlighet',
    'Space directory' => 'Forumkatalog',
    'Space is invisible!' => 'Forumet är osynligt!',
    'Spaces' => 'Forum',
    'Status' => 'Status',
    'Stream' => 'Flöde',
    'Tags' => 'Taggar',
    'There is no pending invite!' => 'Det finns inga väntande inbjudningar!',
    'This action is only available for workspace members!' => 'Detta val är bara tillgängligt för forummedlemmar!',
    'This user is already a member of this space.' => 'Användaren är redan medlem i detta forum.',
    'This user is not a member of this space.' => 'Användaren är inte medlem i detta forum.',
    'To invite users to this space, please type their names below to find and pick them.' => 'För att bjuda in användare till detta forum, skriv namnen nedan för att hitta och välja rätt person.',
    'Try other keywords or remove filters.' => 'Prova andra sökord eller ta bort filter.',
    'Updated At' => 'Uppdaterad',
    'Updated By' => 'Uppdaterad av',
    'Updated by' => 'Uppdaterad av',
    'User \'{username}\' is already a member of this space!' => 'Användare \'{username}\' är redan medlem i detta forum!',
    'User invitations have been added to the queue' => 'Inbjudningar till användare har lagts till i kön',
    'User memberships have been added to the queue' => 'Medlemskap för användare har lagts till i kön',
    'User not found!' => 'Användaren hittades inte!',
    'Users' => 'Användare',
    'Users has been invited.' => 'Användare har blivit inbjudna',
    'Visibility' => 'Synlighet',
    'Visible for all (members and guests)' => 'Synligt för alla (medlemmar &amp; gäster)',
    'Would you like to end your membership in Space {spaceName}?' => 'Vill du avsluta ditt medlemskap i forumet {spaceName}?',
    'Would you like to unfollow Space {spaceName}?' => 'Vill du sluta följa forumet {spaceName}?',
    'Would you like to unfollow {userName}?' => 'Vill du sluta följa {userName}?',
    'Would you like to withdraw your request to join Space {spaceName}?' => 'Vill du dra tillbaka din begäran om att gå med i forumet {spaceName}?',
    'You are not allowed to join this space!' => 'Du har inte tillstånd att gå med i forumet!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Du kan också bjuda in externa användare som inte är registrerade. Lägg bara till deras e-postadresser åtskilda av komma.',
    'You cannot create private visible spaces!' => 'Du kan inte skapa synliga privata forum!',
    'You cannot create public visible spaces!' => 'Du kan inte skapa synliga publika forum!',
    'You need to login to view contents of this space!' => 'Du behöver logga in för att se innehållet i detta forum!',
    'Your request was successfully submitted to the space administrators.' => 'Din förfrågan skickades till administratörerna för forumet.',
    '{count} members' => '{count} medlemmar',
    '{email} is not valid!' => '{email} är ogiltig!',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/space/messages/sv/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Det här forumet saknar innehåll!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Det här forumet saknar innehåll!</b><br>Börja med att göra ett inlägg här...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Du är inte medlem i det här forumet och det finns ännu inget publikt innehåll!</b>',
    '<strong>About</strong> the Space' => '<strong>Om</strong> forumet',
    '<strong>About</strong> your membership' => '<strong>Om</strong> ditt medlemskap',
    '<strong>Confirm</strong> image deletion' => '<strong>Bekräfta</strong> borttag av bild',
    '<strong>Invite</strong> members' => '<strong>Bjud in</strong> medlemmar',
    '<strong>New</strong> member request' => '<strong>Nya</strong> medlemsförfrågningar',
    '<strong>New</strong> spaces' => '<strong>Nya</strong> forum',
    '<strong>Request</strong> Membership' => '<strong>Ansök om</strong> medlemskap i forumet',
    '<strong>Space</strong> followers' => '<strong>Forumets</strong> följare',
    '<strong>Space</strong> members' => '<strong>Forumets</strong> medlemmar',
    '<strong>Space</strong> menu' => '<strong>Forum</strong> meny',
    '<strong>Space</strong> tags' => '<strong>Forum</strong>-taggar',
    '<strong>Spaces</strong>' => '<strong>Forum</strong>',
    'About' => 'Om',
    'Accept' => 'Acceptera',
    'Accept Invite' => 'Acceptera inbjudan',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Vänligen presentera dig lite kort, för att bli godkänd som medlem i detta forum.',
    'Add users without invitation' => 'Lägg till användare utan inbjudan',
    'Admin' => 'Admin',
    'Administrator:' => 'Administratör:',
    'Administrators' => 'Administratörer',
    'Any' => 'Några',
    'Archived' => 'Arkiverad',
    'As owner you cannot revoke your membership!' => 'Som ägare kan du inte avsäga ditt medlemskap!',
    'Blocked users' => 'Blockerade användare',
    'By Name' => 'Vid namn',
    'Cancel' => 'Avbryt',
    'Change visibility' => 'Ändra synlighet',
    'Close' => 'Stäng',
    'Color' => 'Färg',
    'Could not request membership!' => 'Kunde inte begära medlemskap!',
    'Create new link' => 'Skapa ny länk',
    'Created At' => 'Skapad',
    'Created By' => 'Skapad av',
    'Decline' => 'Avböj',
    'Decline Invite' => 'Avböj inbjudan',
    'Default' => 'Standard',
    'Default content visibility' => 'Innehållets synlighet som standard',
    'Delete' => 'Ta bort',
    'Description' => 'Beskrivning',
    'Do you really want to delete your profile image?' => 'Vill du verkligen radera profilbilden?',
    'Do you really want to delete your title image?' => 'Vill du verkligen radera titelbilden?',
    'Done' => 'Klart',
    'Email addresses' => 'E-postadress',
    'Everyone can enter' => 'Vem som helst kan gå med',
    'Find Spaces by their description or by their tags' => 'Hitta forum genom deras beskrivning eller efter deras taggar',
    'Follow' => 'Följ',
    'Followers' => 'Följare',
    'Following' => 'Följer',
    'Guests' => 'Gäster',
    'Hide About Page' => 'Dölj sidan "Om"',
    'Hide Activity Sidebar Widget' => 'Dölj widget för aktivitetssidofält',
    'Hide Followers' => 'Dölj följare',
    'Hide Members' => 'Dölj medlemmar',
    'Homepage' => 'Hemsida',
    'Homepage (Non-members)' => 'Hemsida (icke-medlemmar)',
    'I want to become a member because...' => 'Jag vill bli medlem för att...',
    'Invite' => 'Bjud in',
    'Invite and request' => 'Inbjudan och förfrågan',
    'Invite by email' => 'Inbjudan via e-post',
    'Invite by link' => 'Bjud in via länk',
    'Invite link' => 'Inbjudningslänk',
    'Invites' => 'Inbjudningar',
    'Join' => 'Anslut',
    'Join Policy' => 'Policy för att ansluta',
    'Last Visit' => 'Senaste besök',
    'Leave' => 'Lämna',
    'Login' => 'Logga in',
    'Max. 100 characters.' => 'Max 100 tecken',
    'Member' => 'Medlem',
    'Member since' => 'Medlem sedan',
    'Members' => 'Medlemmar',
    'Moderator' => 'Moderator',
    'Moderator:' => 'Moderator:',
    'Moderators' => 'Moderatorer',
    'My Space List' => 'Min lista med forum',
    'My space summary' => 'Min forumöversikt',
    'Name' => 'Namn',
    'Name / Sort order' => 'Namn / Sorteringsordning',
    'Neither..nor' => 'Varken eller',
    'New user by e-mail (comma separated)' => 'Ny användare via e-post (komma separerade)',
    'New user?' => 'Ny användare?',
    'Newest first' => 'Nyast först',
    'No results found!' => 'Inga resultat funna!',
    'No spaces found.' => 'Inga forum funna.',
    'Oldest first' => 'Äldst först',
    'Only by invite' => 'Endast via inbjudan',
    'Originator User ID' => 'Ursprungligt användar ID',
    'Owner' => 'Ägare',
    'Owner:' => 'Ägare:',
    'Pending' => 'Väntar',
    'Pick users' => 'Välj användare',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Observera att alla länkar som du tidigare har skapat blir ogiltiga så snart du skapar en ny. Vill du fortsätta?',
    'Posts' => 'Inlägg',
    'Private' => 'Privat',
    'Private (Invisible)' => 'Privat (osynlig)',
    'Public' => 'Publik',
    'Public (Members & Guests)' => 'Publik (medlemmar &amp; gäster)',
    'Public (Members only)' => 'Publik (endast medlemmar)',
    'Public (Registered users only)' => 'Publik (endast registrerade användare)',
    'Request Message' => 'Begär meddelande',
    'Role' => 'Roll',
    'Search...' => 'Sök...',
    'See all' => 'Se alla',
    'Select all registered users' => 'Välj alla registrerade användare',
    'Send' => 'Skicka',
    'Send the link via email' => 'Skicka länken via e-post',
    'Settings' => 'Inställningar',
    'Settings could not be saved!' => 'Inställningarna kunde inte sparas!',
    'Show all' => 'Visa alla',
    'Show as List' => 'Visa som lista',
    'Shown on About Page.' => 'Visas på Om-sidan',
    'Sorry, you are not allowed to leave this space!' => 'Tyvärr, du har inte tillåtelse att lämna detta forum!',
    'Sorting' => 'Sortering',
    'Space' => 'Forum',
    'Space Visibility' => 'Forumets synlighet',
    'Space directory' => 'Forumkatalog',
    'Space is invisible!' => 'Forumet är osynligt!',
    'Spaces' => 'Forum',
    'Status' => 'Status',
    'Stream' => 'Flöde',
    'Tags' => 'Taggar',
    'The default homepage for members of this Space' => 'Standardsidan för medlemmar i denna forumyta',
    'The default homepage for non-members and guests visiting this Space' => 'Standardsidan för icke-medlemmar och gäster som besöker denna forumyta',
    'The secure link has been copied in your clipboard!' => 'Den säkra länken har kopierats till ditt urklipp!',
    'There is no pending invite!' => 'Det finns inga väntande inbjudningar!',
    'This action is only available for workspace members!' => 'Detta val är bara tillgängligt för forummedlemmar!',
    'This user is already a member of this space.' => 'Användaren är redan medlem i detta forum.',
    'This user is not a member of this space.' => 'Användaren är inte medlem i detta forum.',
    'To invite users to this space, please type their names below to find and pick them.' => 'För att bjuda in användare till detta forum, skriv namnen nedan för att hitta och välja rätt person.',
    'Try other keywords or remove filters.' => 'Prova andra sökord eller ta bort filter.',
    'Updated At' => 'Uppdaterad',
    'Updated By' => 'Uppdaterad av',
    'Updated by' => 'Uppdaterad av',
    'User \'{username}\' is already a member of this space!' => 'Användare \'{username}\' är redan medlem i detta forum!',
    'User invitations have been added to the queue' => 'Inbjudningar till användare har lagts till i kön',
    'User memberships have been added to the queue' => 'Medlemskap för användare har lagts till i kön',
    'User not found!' => 'Användaren hittades inte!',
    'Users' => 'Användare',
    'Users has been invited.' => 'Användare har blivit inbjudna',
    'Visibility' => 'Synlighet',
    'Visible for all (members and guests)' => 'Synligt för alla (medlemmar &amp; gäster)',
    'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Varning: Om du ändrar inställningarna för synlighet för en forumyta från offentligt till privat, kommer allt innehåll inom det forumet, inklusive inlägg, kommentarer, bilagor etc. också att vara privat. Detta innebär att icke-medlemmar inte längre kommer att kunna se, komma åt eller interagera med något av innehållet i den forumytan.',
    'Would you like to end your membership in Space {spaceName}?' => 'Vill du avsluta ditt medlemskap i forumet {spaceName}?',
    'Would you like to unfollow Space {spaceName}?' => 'Vill du sluta följa forumet {spaceName}?',
    'Would you like to unfollow {userName}?' => 'Vill du sluta följa {userName}?',
    'Would you like to withdraw your request to join Space {spaceName}?' => 'Vill du dra tillbaka din begäran om att gå med i forumet {spaceName}?',
    'You are not allowed to join this space!' => 'Du har inte tillstånd att gå med i forumet!',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Du kan också bjuda in externa användare via e-post, som inte är registrerade. Lägg bara till deras e-postadresser separerade med kommatecken.',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'Du kan bjuda in externa användare som för närvarande inte är registrerade via länk. Allt du behöver göra är att dela denna säkra länk med dem.',
    'You cannot create private visible spaces!' => 'Du kan inte skapa synliga privata forum!',
    'You cannot create public visible spaces!' => 'Du kan inte skapa synliga publika forum!',
    'You need to login to view contents of this space!' => 'Du behöver logga in för att se innehållet i detta forum!',
    'Your Message' => 'Meddelande för ansökan',
    'Your request was successfully submitted to the space administrators.' => 'Din förfrågan skickades till administratörerna för forumet.',
    '{count} members' => '{count} medlemmar',
    '{email} is not valid!' => '{email} är ogiltig!',
    '<strong>Leave</strong> Space' => '',
    'Add as Default Space for new users' => '',
    'Advanced Spaces Search' => '',
    'Default Stream Sort' => '',
    'Incorrect name, try again.' => '',
    'Space Name' => '',
    'Stream Sort' => '',
];
